@@ -1,10 +1,10 @@
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
 %  Adapter file for YAP Prolog 6.3.4 and later versions
-%  Last updated on November 28, 2019
+%  Last updated on January 6, 2020
 %
 %  This file is part of Logtalk <https://logtalk.org/>
-%  Copyright 1998-2019 Paulo Moura <pmoura@logtalk.org>
+%  Copyright 1998-2020 Paulo Moura <pmoura@logtalk.org>
 %
 %  Licensed under the Apache License, Version 2.0 (the "License");
 %  you may not use this file except in compliance with the License.
@@ -635,8 +635,9 @@
 	% (sloppy replacement for the use_module/1-2 directives)
 	'$lgt_yap_directive_expansion'(use_module(File), Expanded).
 
-'$lgt_yap_directive_expansion'(reexport(File), (:- reexport(Module, Exports))) :-
-	'$lgt_yap_list_of_exports'(File, Module, Exports).
+'$lgt_yap_directive_expansion'(reexport(File), [(:- use_module(Module, Exports)), (:- export(Exports))]) :-
+	'$lgt_yap_list_of_exports'(File, Module, Exports0),
+	'$lgt_yap_fix_predicate_aliases'(Exports0, Exports).
 
 '$lgt_yap_directive_expansion'(reexport(File, Exports0), (:- reexport(Module, Exports))) :-
 	'$lgt_yap_list_of_exports'(File, Module, OriginalExports),
@@ -1014,12 +1015,10 @@ user:goal_expansion('::'(Object, Message), ExpandedGoal) :-
 
 % '$lgt_user_module_qualification'(@callable, -callable)
 
-term_expansion(
-		'$lgt_user_module_qualification'(_, _),
-		'$lgt_user_module_qualification'(Goal, Module:Goal)) :-
-	prolog_load_context(module, Module).
-
-'$lgt_user_module_qualification'(_, _).
+:- initialization((
+	prolog_load_context(module, Module),
+	assert_static('$lgt_user_module_qualification'(Goal, Module:Goal))
+)).
 
 
 
