@@ -1,7 +1,7 @@
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
 %  This file is part of Logtalk <https://logtalk.org/>
-%  Copyright 1998-2019 Paulo Moura <pmoura@logtalk.org>
+%  Copyright 1998-2020 Paulo Moura <pmoura@logtalk.org>
 %
 %  Licensed under the Apache License, Version 2.0 (the "License");
 %  you may not use this file except in compliance with the License.
@@ -22,7 +22,7 @@
 
 	:- module(module).
 
-	:- export((p/1, q/1, r/1)).
+	:- export((p/1, q/1, r/1, s/2)).
 
 	p(1).
 
@@ -30,9 +30,12 @@
 
 	r(3).
 
+	s(1, one).
+	s(2, two).
+
 :- else.
 
-	:- module(module, [p/1, q/1, r/1]).
+	:- module(module, [p/1, q/1, r/1, s/2]).
 
 	p(1).
 
@@ -40,4 +43,7 @@
 
 	r(3).
 
+	s(1, one).
+	s(2, two).
+
 :- endif.
